# imgddcore

`imgddcore` is an **internal sub-crate** of the [imgdd](https://crates.io/crates/imgdd) library,
providing its core functionalities.

**Important Note**: This crate is **not intended for external usage**. Please refer to the main
[imgdd crate](https://crates.io/crates/imgdd) for intended usage.